@@ -1,5 +1,6 @@
 import qualified Suites.Bimap
 import qualified Suites.Map
+import qualified Suites.Set
 import Test.Tasty
 import Prelude
 
@@ -8,5 +9,6 @@ main =
   defaultMain
     . testGroup ""
     $ [ testGroup "Bimap" Suites.Bimap.tests,
-        testGroup "Map" Suites.Map.tests
+        testGroup "Map" Suites.Map.tests,
+        testGroup "Set" Suites.Set.tests
       ]
